==> haskell-wl-pprint-text-1.2.0.1-10-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-wl-pprint-text.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 wl-pprint-text
version:              1.2.0.1
visibility:           public
id:                   wl-pprint-text-1.2.0.1-EluLDWNsmVp2uUAh1N4fAU
key:                  wl-pprint-text-1.2.0.1-EluLDWNsmVp2uUAh1N4fAU
license:              BSD-3-Clause
copyright:            2007 Daan Leijen, 2010 Ivan Lazar Miljenovic
maintainer:           Ivan.Miljenovic@gmail.com
author:               Ivan Lazar Miljenovic
synopsis:             A Wadler/Leijen Pretty Printer for Text values
description:          A clone of wl-pprint for use with the text library.
category:             Text
abi:                  832bf29109d3eb9e16dd0e61c8421847
exposed:              True
exposed-modules:
    Text.PrettyPrint.Leijen.Text Text.PrettyPrint.Leijen.Text.Monadic

import-dirs:          /usr/lib/ghc-8.10.5/site-local/wl-pprint-text-1.2.0.1
library-dirs:         /usr/lib/ghc-8.10.5/site-local/wl-pprint-text-1.2.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.5/wl-pprint-text-1.2.0.1
hs-libraries:         HSwl-pprint-text-1.2.0.1-EluLDWNsmVp2uUAh1N4fAU
depends:
    base-4.14.2.0 base-compat-0.11.2-Eyusxyk2CrTGloLdon9bIK
    text-1.2.4.1

haddock-interfaces:
    /usr/share/doc/haskell-wl-pprint-text/html/wl-pprint-text.haddock

haddock-html:         /usr/share/doc/haskell-wl-pprint-text/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-wl-pprint-text-1.2.0.1-11-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-wl-pprint-text.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 wl-pprint-text
version:              1.2.0.1
visibility:           public
id:                   wl-pprint-text-1.2.0.1-DsCJ2fPlaaFCoBzGhODYsl
key:                  wl-pprint-text-1.2.0.1-DsCJ2fPlaaFCoBzGhODYsl
license:              BSD-3-Clause
copyright:            2007 Daan Leijen, 2010 Ivan Lazar Miljenovic
maintainer:           Ivan.Miljenovic@gmail.com
author:               Ivan Lazar Miljenovic
synopsis:             A Wadler/Leijen Pretty Printer for Text values
description:          A clone of wl-pprint for use with the text library.
category:             Text
abi:                  1c01aa3b7b63e3596330486f486ccf72
exposed:              True
exposed-modules:
    Text.PrettyPrint.Leijen.Text Text.PrettyPrint.Leijen.Text.Monadic

import-dirs:          /usr/lib/ghc-9.0.1/site-local/wl-pprint-text-1.2.0.1
library-dirs:         /usr/lib/ghc-9.0.1/site-local/wl-pprint-text-1.2.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/wl-pprint-text-1.2.0.1
hs-libraries:         HSwl-pprint-text-1.2.0.1-DsCJ2fPlaaFCoBzGhODYsl
depends:
    base-4.15.0.0 base-compat-0.11.2-EfuzzJ3SbjR74eBdJgKfBC
    text-1.2.4.1

haddock-interfaces:
    /usr/share/doc/haskell-wl-pprint-text/html/wl-pprint-text.haddock

haddock-html:         /usr/share/doc/haskell-wl-pprint-text/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
